# Release History

## 1.0.0 (08/02/2022)

- Initial Release

- Configured, CHANGELOG, LICENSE, and MANIFEST

- Connect to a samba server remotely

- Connect via hostname, port, username and password

- Download, upload, delete, and move files on the samba server
